@@ -247,3 +247,66 @@ class FoundPrincipalCreated:
 
 class IQueriableAuthenticator(zope.interface.Interface):
     """Indicates the authenticator provides a search UI for principals."""
+
+
+class IPrincipal(zope.security.interfaces.IGroupClosureAwarePrincipal):
+
+    groups = zope.schema.List(
+        title=_("Groups"),
+        description=_(
+            """ids of groups to which the principal directly belongs.
+
+            Plugins may append to this list.  Mutating the list only affects
+            the life of the principal object, and does not persist (so
+            persistently adding groups to a principal should be done by working
+            with a plugin that mutates this list every time the principal is
+            created, like the group folder in this package.)
+            """),
+        value_type=zope.schema.TextLine(),
+        required=False)
+
+
+class IQuerySchemaSearch(zope.interface.Interface):
+    """An interface for searching using schema-constrained input."""
+
+    schema = zope.interface.Attribute("""
+        The schema that constrains the input provided to the search method.
+
+        A mapping of name/value pairs for each field in this schema is used
+        as the query argument in the search method.
+        """)
+
+    def search(query, start=None, batch_size=None):
+        """Returns an iteration of principal IDs matching the query.
+
+        query is a mapping of name/value pairs for fields specified by the
+        schema.
+
+        If the start argument is provided, then it should be an
+        integer and the given number of initial items should be
+        skipped.
+
+        If the batch_size argument is provided, then it should be an
+        integer and no more than the given number of items should be
+        returned.
+        """
+
+
+class IGroupAdded(zope.interface.Interface):
+    """A group has been added."""
+
+    group = zope.interface.Attribute("""The group that was defined""")
+
+
+class IPrincipalsAddedToGroup(zope.interface.Interface):
+    group_id = zope.interface.Attribute(
+        'the id of the group to which the principal was added')
+    principal_ids = zope.interface.Attribute(
+        'an iterable of one or more ids of principals added')
+
+
+class IPrincipalsRemovedFromGroup(zope.interface.Interface):
+    group_id = zope.interface.Attribute(
+        'the id of the group from which the principal was removed')
+    principal_ids = zope.interface.Attribute(
+        'an iterable of one or more ids of principals removed')
